package ociinstaller

import (
	"github.com/turbot/pipe-fittings/v2/ociinstaller"
)

const (
	ImageTypeDatabase ociinstaller.ImageType = "db"
	ImageTypeFdw      ociinstaller.ImageType = "fdw"
	ImageTypeAssets   ociinstaller.ImageType = "assets"
)
